import * as React from 'react';
import * as ReactDOM from 'react-dom';
import { getComputedStyles } from 'roosterjs-editor-dom';
import { ThemeProvider } from '@fluentui/react/lib/Theme';
import { WindowProvider } from '@fluentui/react/lib/WindowProvider';
/**
 * Create the UI Utilities object for plugins to render additional react components
 * @param container Container DIV of editor
 * @param theme Current theme used by editor
 * @returns A UIUtilities object
 */
export default function createUIUtilities(container, theme) {
    return {
        renderComponent: function (element) {
            var doc = container.ownerDocument;
            var div = doc.createElement('div');
            doc.body.appendChild(div);
            ReactDOM.render(React.createElement(WindowProvider, { window: doc.defaultView },
                React.createElement(ThemeProvider, { theme: theme }, element)), div);
            return function () {
                ReactDOM.unmountComponentAtNode(div);
                doc.body.removeChild(div);
            };
        },
        isRightToLeft: function () {
            var dir = container && getComputedStyles(container, 'direction')[0];
            return dir == 'rtl';
        },
    };
}
//# sourceMappingURL=createUIUtilities.js.map