import createContextMenuProvider from '../utils/createContextMenuProvider';
import showInputDialog from '../../inputDialog/utils/showInputDialog';
import { safeInstanceOf } from 'roosterjs-editor-dom';
import { setOrderedListNumbering } from 'roosterjs-editor-api';
var ListNumberResetMenuItem = {
    key: 'menuNameListNumberReset',
    unlocalizedText: 'Restart at 1',
    onClick: function (_, editor, node) {
        var li = editor.getElementAtCursor('LI', node);
        setOrderedListNumbering(editor, li, 1);
    },
};
var ListNumberEditMenuItem = {
    key: 'menuNameListNumberEdit',
    unlocalizedText: 'Set numbering value',
    onClick: function (_, editor, node, strings, uiUtilities) {
        var listAndLi = getEditingList(editor, node);
        if (listAndLi) {
            var list = listAndLi.list, li_1 = listAndLi.li;
            var startNumber_1 = list.start;
            for (var child = list.firstChild; child; child = child.nextSibling) {
                if (child === li_1) {
                    break;
                }
                else if (safeInstanceOf(child, 'HTMLLIElement')) {
                    startNumber_1 += 1;
                }
            }
            showInputDialog(uiUtilities, 'menuNameListNumberEdit', 'Set numbering value', {
                value: {
                    labelKey: 'dialogTextSetListNumber',
                    unlocalizedLabel: 'Set value to',
                    initValue: startNumber_1.toString(),
                },
            }, strings).then(function (values) {
                editor.focus();
                if (values) {
                    var result = parseInt(values.value);
                    if (result > 0 && result != startNumber_1) {
                        setOrderedListNumbering(editor, li_1, Math.floor(result));
                    }
                }
            });
        }
    },
};
function getEditingList(editor, node) {
    var li = editor.getElementAtCursor('LI', node);
    var list = li && editor.getElementAtCursor('ol', li);
    return (list === null || list === void 0 ? void 0 : list.isContentEditable) ? { list: list, li: li } : null;
}
/**
 * Create a new instance of ContextMenuProvider to support list number editing functionalities in context menu
 * @returns A new ContextMenuProvider
 */
export default function createListEditMenuProvider(strings) {
    return createContextMenuProvider('listEdit', [ListNumberResetMenuItem, ListNumberEditMenuItem], strings, function (editor, node) { return !!getEditingList(editor, node); });
}
//# sourceMappingURL=createListEditMenuProvider.js.map