"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.insertLink = void 0;
var showInputDialog_1 = require("../../../inputDialog/utils/showInputDialog");
var roosterjs_editor_api_1 = require("roosterjs-editor-api");
/**
 * @internal
 * "Insert link" button on the format ribbon
 */
exports.insertLink = {
    key: 'buttonNameInsertLink',
    unlocalizedText: 'Insert link',
    iconName: 'Link',
    isDisabled: function (formatState) { return !!formatState.isMultilineSelection; },
    onClick: function (editor, _, strings, uiUtilities) {
        var _a;
        var existingLink = editor.queryElements('a[href]', 1 /* OnSelection */)[0];
        var url = (existingLink === null || existingLink === void 0 ? void 0 : existingLink.href) || '';
        var displayText = (existingLink === null || existingLink === void 0 ? void 0 : existingLink.textContent) || ((_a = editor.getSelectionRange()) === null || _a === void 0 ? void 0 : _a.toString()) || '';
        var items = {
            url: {
                autoFocus: true,
                labelKey: 'insertLinkDialogUrl',
                unlocalizedLabel: 'Web address (URL)',
                initValue: url,
            },
            displayText: {
                labelKey: 'insertLinkDialogDisplayAs',
                unlocalizedLabel: 'Display as',
                initValue: displayText,
            },
        };
        (0, showInputDialog_1.default)(uiUtilities, 'insertLinkTitle', 'Insert link', items, strings, function (itemName, newValue, values) {
            if (itemName == 'url' && values.displayText == values.url) {
                values.displayText = newValue;
                values.url = newValue;
                return values;
            }
            else {
                return null;
            }
        }).then(function (result) {
            editor.focus();
            if (result &&
                result.displayText &&
                result.url &&
                (result.displayText != displayText || result.url != url)) {
                (0, roosterjs_editor_api_1.createLink)(editor, result.url, result.url, result.displayText);
            }
        });
    },
};
//# sourceMappingURL=insertLink.js.map